@@ -5,15 +5,16 @@
 #include "httpresponse.h"
 #include "httprequesthandler.h"
 
-class FolderContentControllerV2 : public HttpRequestHandler {
-	Q_OBJECT
+class FolderContentControllerV2 : public HttpRequestHandler
+{
+    Q_OBJECT
     Q_DISABLE_COPY(FolderContentControllerV2)
 public:
-	/** Constructor */
+    /** Constructor */
     FolderContentControllerV2();
 
-	/** Generates the response */
-	void service(HttpRequest& request, HttpResponse& response);
+    /** Generates the response */
+    void service(HttpRequest &request, HttpResponse &response) override;
 
 private:
     void serviceContent(const int &library, const qulonglong &folderId, HttpResponse &response);
