@@ -4,28 +4,24 @@
 #include <QObject>
 #include <QtCore>
 
-
-
 class HttpSessionStore;
 class YACReaderHttpSession;
 
-
-
 class YACReaderHttpSessionStore : public QObject
 {
     Q_OBJECT
 public:
-    explicit YACReaderHttpSessionStore(HttpSessionStore *sessionStore, QObject *parent = 0);
+    explicit YACReaderHttpSessionStore(HttpSessionStore *sessionStore, QObject *parent = nullptr);
 
-    void addYACReaderHttpSession(const QByteArray & httpSessionId, YACReaderHttpSession *yacreaderHttpSession);
-    YACReaderHttpSession *getYACReaderSessionHttpSession(const QByteArray & httpSessionId);
+    void addYACReaderHttpSession(const QByteArray &httpSessionId, YACReaderHttpSession *yacreaderHttpSession);
+    YACReaderHttpSession *getYACReaderSessionHttpSession(const QByteArray &httpSessionId);
 
 signals:
 
 public slots:
 
 private:
-    QMap<QByteArray, YACReaderHttpSession*> sessions;
+    QMap<QByteArray, YACReaderHttpSession *> sessions;
     HttpSessionStore *sessionStore;
     QTimer cleanupTimer;
 
